@@ -12,9 +12,9 @@ public class GlpkCallback {
     /**
      * callback function called by native library
      */
-    public static void callback(long lTree) {
+    public static void callback(long cPtr) {
         glp_tree tree;
-        tree = GLPK.glp_java_get_tree_object(lTree);
+        tree = new glp_tree(cPtr, false);
         for (GlpkCallbackListener listener : listeners) {
             listener.callback(tree);
         }
